# A Framework for Benchmarking Clustering Algorithms

Maintained/edited/authored by [Marek Gagolewski](https://www.gagolewski.com).

This project aims to:

* **aggregate, polish, and standardise the existing clustering benchmark
    batteries** referred to across the machine learning and data mining
    literature,
* introduce **new datasets** of different dimensionalities,
    sizes, and cluster types,
* propose a **consistent methodology** for evaluating clustering algorithms.

See <https://clustering-benchmarks.gagolewski.com/> for a detailed description.

For an example study based on this benchmark suite,
see <https://genieclust.gagolewski.com>.


**How to Cite**:
Gagolewski M., *A Framework for Benchmarking Clustering Algorithms*, 2022,
<https://clustering-benchmarks.gagolewski.com>, submitted for publication.
